PyRocky
=======

|pyansys| |MIT| |python| |pypi| |codecov| |MIT| |black| |pre-commit|

PyRocky is a Python client library to create, run, and postprocess
particle dynamics simulations using `Ansys Rocky <https://www.ansys.com/products/fluids/ansys-rocky>`_,
the most powerful DEM (discrete element method) software in the market.

Documentation and issues
------------------------

Documentation for the latest stable release of PyRocky is hosted at
`PyRocky documentation <https://rocky.docs.pyansys.com/version/stable/index.html>`_.

The documentation has five sections:

- `Getting started <https://rocky.docs.pyansys.com/version/stable/getting_started/index.html>`_: Learn
  how to install PyRocky in user mode and then launch it.
- `User guide <https://rocky.docs.pyansys.com/version/stable/user_guide/index.html>`_: Understand how to
  use Rocky PrePost Scripting with PyRocky.
- `API reference <https://rocky.docs.pyansys.com/version/stable/api/index.html>`_: Explore PyRocky
  available methods and classes.
- `Examples <https://rocky.docs.pyansys.com/version/stable/examples/index.html>`_: Explore end-to-end
  examples that show how to use PyRocky.
- `Contribute <https://rocky.docs.pyansys.com/version/stable/contributing.html>`_: Learn how to
  contribute to the PyRocky codebase or documentation.

In the upper right corner of the documentation's title bar, there is an option
for switching from viewing the documentation for the latest stable release
to viewing the documentation for the development version or previously
released versions.

On the `PyRocky Issues <https://github.com/ansys/pyrocky/issues>`_ page, you can
create issues to report bugs and request new features. On the
`Discussions <https://discuss.ansys.com/>`_ page on the Ansys Developer portal,
you can post questions, share ideas, and get community feedback.

To reach the PyAnsys project support team, email `PyAnsys Core team <pyansys.core@ansys.com>`_.

License
-------

PyRocky is licensed under the `MIT License <https://github.com/ansys/pyrocky/blob/main/LICENSE>`_.

PyRocky makes no commercial claim over Ansys whatsoever. This library extends the
functionality of Ansys Rocky by adding a Python interface without changing the
core behavior or license of the original software. The use of PyRocky requires a
legally licensed copy of Ansys Rocky.

To get a copy of Ansys Rocky, see the `Ansys Rocky <https://www.ansys.com/products/fluids/ansys-rocky>`_
page on the Ansys website.


.. BADGES
.. |pyansys| image:: https://img.shields.io/badge/Py-Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://docs.pyansys.com/
   :alt: PyAnsys

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |python| image:: https://img.shields.io/pypi/pyversions/ansys-rocky-core?logo=pypi
   :target: https://pypi.org/project/ansys-rocky-core/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/ansys-rocky-core.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/ansys-rocky-core
   :alt: PyPI

.. |codecov| image:: https://codecov.io/gh/ansys/pyrocky/graph/badge.svg?token=UZIC7XT5WE
   :target: https://codecov.io/gh/ansys/pyrocky
   :alt: Codecov

.. |GH-CI| image:: https://github.com/ansys/pyrocky/actions/workflows/ci_cd.yml/badge.svg
   :target: https://github.com/ansys/pyrocky/actions/workflows/ci_cd.yml
   :alt: GH-CI

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg?style=flat
   :target: https://github.com/psf/black
   :alt: Black

.. |pre-commit| image:: https://results.pre-commit.ci/badge/github/ansys/pyrocky/main.svg
   :target: https://results.pre-commit.ci/latest/github/ansys/pyrocky/main
   :alt: pre-commit.ci
